sboxanalyzer: Tool for analyzing S-boxes and Boolean functions against differential, linear, differential-linear, boomerang, and integral attacks
=================================================================================================================================================

Description
-----------

Tool for analyzing S-boxes and Boolean functions against differential, linear, differential-linear, boomerang, and integral attacks

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/sboxanalyzer/

